---
name: Feature
about: Add/Implement Feature
title: <Insert Title>
labels: feature
assignees: ''

---

# Summary
<!---
A short description of the feature (TL;DR)
--->

# Details
<!---
A detailed description about what should be added, background, links, context information
and usage example(s) of the feature.
--->

## Background & Context
<!---
What is the motivation for the feature?
Assessment of the feature. Pros & cons, solutions and decisions concerning the feature (reasoning).
--->

## Examples
<!---
Example usage(s) of the feature.
--->

## References
<!---
Further references to e.g. other information resources like links to specification(s) etc.
--->

# Task(s)
<!---
A task list containing common tasks associated with this kind of issue, but also tasks specific to this issue.

e.g.:
- [ ] Add feature XYZ
- [ ] Bump version number
- [ ] Update documentation
- [ ] Update changelog
- [ ] ...
--->
